==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/SAPDB/SQLStudio/Studio_Connection.cpp <==
/*
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

/*!**********************************************************************

  module: Studio_Connection.cpp

  -----------------------------------------------------------------------

  mail to:  sapdb-general@sap.com

  special area: SQLStudio

  description:  class for handling a database connection				

  see also:		/


************************************************************************/




/*=======================================================================
 *  INCLUDES
 *=====================================================================*/

#include "SAPDB/SQLStudio/Studio_Connection.hpp"



Studio_Connection::Studio_Connection(const sapdbwa_DBCPoolP pDbcPool,sapdbwa_DBCExclType nPoolingMode)
{
	m_pDbcHandle = NULL;
	m_pDbcPool = pDbcPool;	

	m_nAutoCommit = SQL_AUTOCOMMIT_ON;
	m_eSQLMode = cpr_kind_internal;
	m_nIsoLevel = SQL_TXN_READ_COMMITTED;

	m_nPoolingMode = nPoolingMode;
}

Studio_Connection::Studio_Connection(const Studio_Connection& oCon)
{
	m_pDbcHandle = NULL;

	m_sDBServer = oCon.m_sDBServer;
	m_sDBName = oCon.m_sDBName;
	m_sDBUser = oCon.m_sDBUser;
	m_sPassWord = oCon.m_sPassWord;

	m_sODBCDriver = oCon.m_sODBCDriver;

	m_pDbcPool = oCon.m_pDbcPool;

	m_nAutoCommit = oCon.m_nAutoCommit;
    m_eSQLMode = oCon.m_eSQLMode;
    m_nIsoLevel = oCon.m_nIsoLevel;
	m_nPoolingMode = oCon.m_nPoolingMode;
}
	

Studio_Connection::~Studio_Connection()
{
	SAPDB_DynamicUTF8String	sError;
	dbLogOff(sError);
}


SAPDB_Bool Studio_Connection::dbLogOff(SAPDB_DynamicUTF8String&	sError){


	if (m_pDbcPool != NULL && m_pDbcHandle != NULL) {

		if (sapdbwa_DBCDisconnect(m_pDbcPool,m_pDbcHandle ) == false){

			sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
			if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){

				char *psError = (char*)sapdbwa_GetErrMsg(pError);
				//convert from ascii because WA is not unicode
				sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));

				//destroy database connection
				sapdbwa_DestroyDBC(m_pDbcHandle);
				m_pDbcHandle = NULL;	

				return SAPDB_FALSE;
			}
		}	
		//destroy database connection
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
	}

	return SAPDB_TRUE; 
}


SAPDB_Bool Studio_Connection::dbLogOn(SAPDB_DynamicUTF8String&	sError)
{

	//dbc handle
	SQLHDBC			hdbc = 0;
	SQLHENV			henv = 0;

	SAPDB_Char* szpConvert = NULL;	

	SAPDB_Char sAsciiPassWord[128];
	memset(sAsciiPassWord,0,128);
	SAPDB_Char	sAsciiDBUser[128];
	memset(sAsciiDBUser,0,128);
	SAPDB_Char	sAsciiDBServer[128];
	memset(sAsciiDBServer,0,128);
	SAPDB_Char	sAsciiDBName[128];
	memset(sAsciiDBName,0,128);

	SAPDB_Char	sAsciiODBCDriver[128];
	memset(sAsciiODBCDriver,0,128);

	char *psError = NULL;
	sapdbwa_ErrP pError = NULL;

	m_pDbcHandle = sapdbwa_CreateDBC();

	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_AUTOCOMMIT, m_nAutoCommit) == false) {

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        psError = (char*) sapdbwa_GetErrMsg(pError);
		//convert from ascii because WA is not unicode
		sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }

	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_SQLMODE, m_eSQLMode) == false){

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        psError = (char*) sapdbwa_GetErrMsg(pError);
		//convert from ascii because WA is not unicode
		sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }

	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_TXN_ISOLATION, m_nIsoLevel) == false) {

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        psError = (char*) sapdbwa_GetErrMsg(pError);
		//convert from ascii because WA is not unicode
		sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }

	//NOT UNICODE BECAUSE OF WA
	SAPDB_DynamicUTF8String		sCopyOfDBServer = m_sDBServer;
	SAPDB_DynamicUTF8String		sCopyOfDBName = m_sDBName;
	SAPDB_DynamicUTF8String		sCopyOfDBUser = m_sDBUser;
	SAPDB_DynamicUTF8String		sCopyOfPassWord = m_sPassWord;
	SAPDB_DynamicUTF8String		sCopyOfODBCDriver = m_sODBCDriver;;

	if(sCopyOfDBServer.Size() > 0)
		assert(sCopyOfDBServer.ConvertToASCII_Latin1((char*)sAsciiDBServer,sAsciiDBServer+sizeof (sAsciiDBServer),szpConvert) == SAPDB_UTF8Basis::Success);

	if(sCopyOfDBName.Size() > 0)
		assert(sCopyOfDBName.ConvertToASCII_Latin1((char*)sAsciiDBName,sAsciiDBName+sizeof (sAsciiDBName),szpConvert) == SAPDB_UTF8Basis::Success);

	if(sCopyOfDBUser.Size() > 0)
		assert(sCopyOfDBUser.ConvertToASCII_Latin1((char*)sAsciiDBUser,sAsciiDBUser+sizeof (sAsciiDBUser),szpConvert) == SAPDB_UTF8Basis::Success);

	if(sCopyOfPassWord.Size() > 0)
	   assert(sCopyOfPassWord.ConvertToASCII_Latin1(sAsciiPassWord,sAsciiPassWord+sizeof (sAsciiPassWord),szpConvert) == SAPDB_UTF8Basis::Success);

	if(sCopyOfODBCDriver.Size() > 0)
	   assert(sCopyOfODBCDriver.ConvertToASCII_Latin1(sAsciiODBCDriver,sAsciiODBCDriver+sizeof (sAsciiODBCDriver),szpConvert) == SAPDB_UTF8Basis::Success);


	//NOT UNICODE BECAUSE OF WA
	if (sapdbwa_DBCConnect(m_pDbcPool,
						   m_pDbcHandle,
						   "",
						   sAsciiODBCDriver,
						   (char*)sAsciiDBServer,
						   (char*)sAsciiDBName,
						   (char*)sAsciiDBUser,
						   (char*)sAsciiPassWord,
						   "", ///tmp/sqltrace
						   0,
						   0,
						   m_nPoolingMode)) {				

		hdbc = sapdbwa_DBCHandle(m_pDbcHandle);
		henv = sapdbwa_DBCEnv(m_pDbcHandle);
		if (hdbc ==  SQL_NULL_HDBC) {			
			
			sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
			if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){

				psError = (char*) sapdbwa_GetErrMsg(pError);
				//convert from ascii because WA is not unicode
				sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));

				//destroy database connection
				sapdbwa_DestroyDBC(m_pDbcHandle);
				m_pDbcHandle = NULL;	

				return SAPDB_FALSE;
			}			
		}
	}
	else {			
		sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
		if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){


			psError = (char*) sapdbwa_GetErrMsg(pError);
			//convert from ascii because WA is not unicode
			sError.ConvertFromASCII_Latin1(psError,psError+strlen(psError));

			//destroy database connection
			sapdbwa_DestroyDBC(m_pDbcHandle);
			m_pDbcHandle = NULL;	

			return SAPDB_FALSE;
		}
	};		

	return SAPDB_TRUE;
}

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/SAPDB/SQLStudio/Studio_Connection.cpp <==
/*
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*/

/*!**********************************************************************

  module: Studio_Connection.cpp

  -----------------------------------------------------------------------

  mail to:  sapdb-general@sap.com

  special area: SQLStudio

  description:  class for handling a database connection				

  see also:		/


************************************************************************/




/*=======================================================================
 *  INCLUDES
 *=====================================================================*/

#include "SAPDB/SQLStudio/Studio_Connection.hpp"



Studio_Connection::Studio_Connection(const sapdbwa_DBCPoolP pDbcPool,sapdbwa_DBCExclType nPoolingMode)
{
	m_pDbcHandle = NULL;
	m_pDbcPool = pDbcPool;	

	m_nAutoCommit = SQL_AUTOCOMMIT_ON;
	m_eSQLMode = cpr_kind_internal;
	m_nIsoLevel = SQL_TXN_READ_COMMITTED;

	m_nPoolingMode = nPoolingMode;
}

Studio_Connection::Studio_Connection(const Studio_Connection& oCon)
{
	m_pDbcHandle = NULL;

	m_sDBServer = oCon.m_sDBServer;
	m_sDBName = oCon.m_sDBName;
	m_sDBUser = oCon.m_sDBUser;
	m_sPassWord = oCon.m_sPassWord;

	m_sODBCDriver = oCon.m_sODBCDriver;

	m_pDbcPool = oCon.m_pDbcPool;

	m_nAutoCommit = oCon.m_nAutoCommit;
    m_eSQLMode = oCon.m_eSQLMode;
    m_nIsoLevel = oCon.m_nIsoLevel;
	m_nPoolingMode = oCon.m_nPoolingMode;
}
	

Studio_Connection::~Studio_Connection()
{
	Tools_DynamicUTF8String	sError;
	dbLogOff(sError);
}


SAPDB_Bool Studio_Connection::dbLogOff(Tools_DynamicUTF8String&	sError){


	if (m_pDbcPool != NULL && m_pDbcHandle != NULL) {

		if (sapdbwa_DBCDisconnect(m_pDbcPool,m_pDbcHandle ) == false){

			sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
			if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){

				sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
				//destroy database connection
				sapdbwa_DestroyDBC(m_pDbcHandle);
				m_pDbcHandle = NULL;	

				return SAPDB_FALSE;
			}
		}	
		//destroy database connection
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
	}

	return SAPDB_TRUE; 
}


SAPDB_Bool Studio_Connection::dbLogOn(Tools_DynamicUTF8String&	sError)
{

	//dbc handle
	SQLHDBC			hdbc = 0;
	SQLHENV			henv = 0;		
	sapdbwa_ErrP pError = NULL;

	m_pDbcHandle = sapdbwa_CreateDBC();

    // http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1118845
    // The cast is fine because ODBC re-casts this value back to its appropriate type
    // depending on the attribute type
	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_AUTOCOMMIT, (SQLPOINTER) m_nAutoCommit) == false) {

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }

    // http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1118845
    // The cast is fine because ODBC re-casts this value back to its appropriate type
    // depending on the attribute type
	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_SQLMODE, (SQLPOINTER) m_eSQLMode) == false){

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }

    // http://pts:1080/webpts?wptsdetail=yes&ErrorType=1&ErrorID=1118845
    // The cast is fine because ODBC re-casts this value back to its appropriate type
    // depending on the attribute type
	if (sapdbwa_DBCSetAttr(m_pDbcHandle, SQL_TXN_ISOLATION, (SQLPOINTER) m_nIsoLevel) == false) {

		pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
        sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
		sapdbwa_DestroyDBC(m_pDbcHandle);
		m_pDbcHandle = NULL;	
        return SAPDB_FALSE;
    }	

	if (sapdbwa_DBCConnect(m_pDbcPool,
						   m_pDbcHandle,
						   "",
						   (char*)m_sODBCDriver.StrPtr(),
						   (char*)m_sDBServer.StrPtr(),
						   (char*)m_sDBName.StrPtr(),
						   (char*)m_sDBUser.StrPtr(),
						   (char*)m_sPassWord.StrPtr(),
						   "", ///tmp/sqltrace
						   0,
						   0,
						   m_nPoolingMode)) {				

		hdbc = sapdbwa_DBCHandle(m_pDbcHandle);
		henv = sapdbwa_DBCEnv(m_pDbcHandle);
		if (hdbc ==  SQL_NULL_HDBC) {			
			
			sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
			if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){

				sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
				//destroy database connection
				sapdbwa_DestroyDBC(m_pDbcHandle);
				m_pDbcHandle = NULL;	

				return SAPDB_FALSE;
			}			
		}
	}
	else {			
		sapdbwa_ErrP pError =  sapdbwa_DBCGetErr(m_pDbcHandle);
		if (sapdbwa_GetErrId(pError) != sapdbwa_Error_NoError){


			sError = Tools_DynamicUTF8String((SAPDB_UTF8*) sapdbwa_GetErrMsg(pError));
			//destroy database connection
			sapdbwa_DestroyDBC(m_pDbcHandle);
			m_pDbcHandle = NULL;	

			return SAPDB_FALSE;
		}
	};		

	return SAPDB_TRUE;
}
